
#line 3 "<stdout>"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 33
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;
#endif /* ! C99 */

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

#if __STDC__

#define YY_USE_CONST

#endif	/* __STDC__ */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE defargsYYrestart(defargsYYin  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#define YY_BUF_SIZE 262144
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

extern int defargsYYleng;

extern FILE *defargsYYin, *defargsYYout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up defargsYYtext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up defargsYYtext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

/* The following is because we cannot portably get our hands on size_t
 * (without autoconf's help, which isn't available because we want
 * flex-generated scanners to compile on their own).
 */

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef unsigned int yy_size_t;
#endif

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via defargsYYrestart()), so that the user can continue scanning by
	 * just pointing defargsYYin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = 0; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when defargsYYtext is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int defargsYYleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = (char *) 0;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow defargsYYwrap()'s to do buffer switches
 * instead of setting up a fresh defargsYYin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void defargsYYrestart (FILE *input_file  );
void defargsYY_switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE defargsYY_create_buffer (FILE *file,int size  );
void defargsYY_delete_buffer (YY_BUFFER_STATE b  );
void defargsYY_flush_buffer (YY_BUFFER_STATE b  );
void defargsYYpush_buffer_state (YY_BUFFER_STATE new_buffer  );
void defargsYYpop_buffer_state (void );

static void defargsYYensure_buffer_stack (void );
static void defargsYY_load_buffer_state (void );
static void defargsYY_init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER defargsYY_flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE defargsYY_scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE defargsYY_scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE defargsYY_scan_bytes (yyconst char *bytes,int len  );

void *defargsYYalloc (yy_size_t  );
void *defargsYYrealloc (void *,yy_size_t  );
void defargsYYfree (void *  );

#define yy_new_buffer defargsYY_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        defargsYYensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            defargsYY_create_buffer(defargsYYin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        defargsYYensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            defargsYY_create_buffer(defargsYYin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

#define defargsYYwrap(n) 1
#define YY_SKIP_YYWRAP

typedef unsigned char YY_CHAR;

FILE *defargsYYin = (FILE *) 0, *defargsYYout = (FILE *) 0;

typedef int yy_state_type;

extern int defargsYYlineno;

int defargsYYlineno = 1;

extern char *defargsYYtext;
#define yytext_ptr defargsYYtext

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
static void yy_fatal_error (yyconst char msg[]  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up defargsYYtext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	defargsYYleng = (size_t) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 45
#define YY_END_OF_BUFFER 46
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_acclist[214] =
    {   0,
        2,    2,   46,   44,   45,   43,   45,   44,   45,    1,
       44,   45,   29,   44,   45,   22,   29,   44,   45,   29,
       44,   45,   29,   44,   45,   29,   44,   45,   29,   44,
       45,   31,   44,   45,   15,   31,   44,   45,   16,   31,
       44,   45,   31,   44,   45,   30,   31,   44,   45,   17,
       31,   44,   45,   18,   31,   44,   45,   20,   31,   44,
       45,   19,   31,   44,   45,   27,   44,   45,    2,   27,
       44,   45,   14,   27,   44,   45,   25,   27,   44,   45,
       27,   44,   45,   27,   44,   45,   14,   27,   44,   45,
       23,   27,   44,   45,   25,   27,   44,   45,   26,   27,

       44,   45,   27,   44,   45,   14,   27,   44,   45,    7,
       29,   44,   45,   29,   44,   45,   14,   29,   44,   45,
       25,   29,   44,   45,   25,   29,   44,   45,   12,   27,
       44,   45,    9,   26,   27,   44,   45,   44,   45,   44,
       45,   44,   45,   44,   45,   36,   41,   44,   45,   40,
       43,   45,   41,   44,   45,   36,   41,   44,   45,   37,
       44,   45,   39,   43,   45,   37,   44,   45,   28,   21,
       16,   30,    2,16392,   13,   26,    3,   10,   11,    9,
       26,   34,   36,   38,   36,   37,   37,   37,   42,   16,
       16,16392, 8200,    6,    6,   35,   36,   42,   37,   42,

       42, 8200,    5,    4,    5,   36,   42,   37,   42,   24,
        4,   32,   33
    } ;

static yyconst flex_int16_t yy_accept[153] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    2,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    4,    6,    8,
       10,   13,   16,   20,   23,   26,   29,   32,   35,   39,
       43,   46,   50,   54,   58,   62,   66,   69,   73,   77,
       81,   84,   87,   91,   95,   99,  103,  106,  110,  114,
      117,  121,  125,  129,  133,  138,  140,  142,  144,  146,
      150,  153,  156,  160,  163,  166,  169,  169,  169,  170,
      171,  171,  172,  173,  174,  174,  174,  175,  175,  175,
      176,  177,  177,  178,  178,  178,  178,  179,  180,  182,

      182,  182,  182,  183,  183,  183,  184,  185,  186,  187,
      188,  189,  190,  191,  192,  192,  192,  192,  193,  194,
      194,  194,  195,  195,  196,  196,  196,  197,  197,  197,
      199,  201,  202,  202,  203,  203,  204,  206,  206,  206,
      206,  208,  210,  211,  212,  212,  213,  213,  213,  213,
      214,  214
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    4,    5,    1,    1,    1,    6,    7,    8,
        9,   10,    1,   11,   12,    1,   13,   14,   15,   15,
       15,   15,   15,   15,   15,   16,   16,   17,    1,   18,
       19,   20,    1,    1,   21,   21,   21,   21,   21,   21,
       21,   21,   21,   21,   21,   21,   21,   21,   21,   21,
       21,   21,   21,   21,   21,   21,   21,   21,   21,   21,
       22,   23,   24,    1,   21,    1,   25,   21,   26,   21,

       27,   21,   21,   21,   28,   21,   21,   29,   21,   30,
       31,   21,   21,   21,   32,   33,   21,   34,   21,   21,
       21,   21,   35,    1,   36,    1,    1,   21,   21,   21,
       21,   21,   21,   21,   21,   21,   21,   21,   21,   21,
       21,   21,   21,   21,   21,   21,   21,   21,   21,   21,
       21,   21,   21,   21,   21,   21,   21,   21,   21,   21,
       21,   21,   21,   21,   21,   21,   21,   21,   21,   21,
       21,   21,   21,   21,   21,   21,   21,   21,   21,   21,
       21,   21,   21,   21,   21,   21,   21,   21,   21,   21,
       21,   21,   21,   21,   21,   21,   21,   21,   21,   21,

       21,   21,   21,   21,   21,   21,   21,   21,   21,   21,
       21,   21,   21,   21,   21,   21,   21,   21,   21,   21,
       21,   21,   21,   21,   21,   21,   21,   21,   21,   21,
       21,   21,   21,   21,   21,   21,   21,   21,   21,   21,
       21,   21,   21,   21,   21,   21,   21,   21,   21,   21,
       21,   21,   21,   21,   21
    } ;

static yyconst flex_int32_t yy_meta[37] =
    {   0,
        1,    2,    3,    1,    1,    1,    1,    1,    4,    5,
        1,    1,    1,    6,    6,    6,    4,    1,    1,    1,
        7,    1,    1,    1,    7,    7,    7,    7,    7,    7,
        7,    7,    7,    7,    1,    1
    } ;

static yyconst flex_int16_t yy_base[170] =
    {   0,
        0,    1,    2,    3,   19,   40,   63,    0,    0,    0,
       10,   18,    0,   92,  127,    0,  161,    0,  194,  226,
      258,  290,   31,   37,    4,   20,  302,  500,  500,   38,
      500,  500,  500,  281,   45,   37,    0,  500,  500,  298,
       49,    0,  500,  500,  500,  500,  500,  296,  100,  101,
      277,   94,   90,  500,  103,    0,  272,  500,  500,  272,
      500,  111,  163,  169,    0,   27,   23,  263,  260,    0,
      500,  277,  102,    0,  500,  107,  115,  171,  500,  500,
      287,  178,    0,  286,  109,  196,  323,  165,  108,  500,
        0,  263,  500,  279,  194,  208,  500,  500,    0,  183,

      261,  185,  500,  253,  253,    0,  500,  182,    0,  207,
      227,  263,  230,    0,  187,  263,  231,  208,  356,  232,
      230,  500,  272,  271,  255,  252,  500,  243,  240,  245,
      232,  500,  262,    0,  231,  500,  500,  259,  205,  179,
        0,    0,  500,  500,  193,  500,  162,  159,   34,  500,
      500,  390,  397,  404,  411,  418,  425,  431,  433,  440,
      442,  449,  456,  458,  465,  472,  478,  485,  492
    } ;

static yyconst flex_int16_t yy_def[170] =
    {   0,
      152,  152,  152,  152,  153,  153,  151,    7,    7,    7,
        7,    7,    7,    7,  151,   15,  153,   17,  154,  154,
      152,  152,  155,  155,  156,  156,  151,  151,  151,  151,
      151,  151,  151,  151,  151,  151,  157,  151,  151,  158,
      151,  159,  151,  151,  151,  151,  151,  151,  160,  151,
      151,  151,  151,  151,  151,  161,  162,  151,  151,  163,
      151,  151,  151,  151,  164,  151,  151,  151,  151,  165,
      151,  151,  165,  166,  151,  166,  151,  151,  151,  151,
      158,  167,  159,  151,  160,  160,  160,  151,  151,  151,
      161,  162,  151,  151,  168,  151,  151,  151,  164,  151,

      169,  151,  151,  151,  151,  165,  151,  165,  166,  166,
      166,  151,  167,  113,  160,  151,  160,   87,  160,  151,
      151,  151,  151,  151,  151,  169,  151,  151,  151,  165,
      166,  151,  160,  119,  151,  151,  151,  151,  151,  151,
      165,  166,  151,  151,  151,  151,  151,  151,  151,  151,
        0,  151,  151,  151,  151,  151,  151,  151,  151,  151,
      151,  151,  151,  151,  151,  151,  151,  151,  151
    } ;

static yyconst flex_int16_t yy_nxt[537] =
    {   0,
      151,  151,   29,   29,   29,   29,   75,   38,   38,   31,
       31,  151,   30,   30,   30,   30,   76,   38,   38,   31,
       31,   29,   75,   33,  102,   38,   38,   43,  100,   44,
       34,   35,   76,   71,   46,   43,  103,   44,   36,   71,
       72,   37,   29,   73,   33,   45,   72,   77,  101,   73,
       78,   34,   35,   45,   77,   79,   79,   78,   77,   36,
      150,   78,   37,   38,   38,   29,   38,   38,   38,   38,
       39,   40,   38,   38,   38,   41,   38,   38,   38,   38,
       38,   38,   38,   42,   38,   38,   38,   42,   42,   42,
       42,   42,   42,   42,   42,   42,   42,   38,   38,   38,

       38,   86,   88,   77,   88,   87,   78,   90,   90,   87,
      115,   77,   88,   89,  108,   89,  110,  120,  112,  111,
      121,   90,   90,   89,  112,  116,   46,   47,   48,   29,
       47,   47,   47,   47,   49,   50,   47,   50,   51,   52,
       47,   47,   47,   47,   53,   54,   55,   56,   57,   47,
       47,   56,   56,   56,   56,   56,   56,   56,   56,   56,
       56,   58,   47,   29,   88,   59,   88,   60,   61,   62,
       96,   62,   34,   35,  112,   89,   97,   89,   61,   81,
       63,   79,   79,  112,  100,  130,  102,  149,  115,  148,
       98,  113,  113,  113,  130,   61,   29,  117,  103,  144,

      124,   87,   64,  116,  101,   87,   52,  125,  125,   96,
      131,  147,  116,   85,   65,   97,  131,   85,   65,   65,
       65,   65,   65,   65,   65,   65,   65,   65,   29,   98,
      131,   81,  117,  135,   64,  135,   87,  146,   52,  131,
       87,  135,  135,  113,  113,  113,   65,  116,  143,  142,
       65,   65,   65,   65,   65,   65,   65,   65,   65,   65,
       29,  137,  141,   86,  140,  144,   66,   87,  138,  138,
       30,   87,  145,  145,  139,  127,   67,  136,  136,  133,
      132,  129,  128,   68,  127,  122,   93,   84,   81,  107,
      105,   69,   29,  104,   95,   93,   90,   84,   66,   81,

       79,  151,   30,  151,  151,  151,  151,  151,   67,  151,
      151,  151,  151,  151,  151,   68,  151,  151,  151,  151,
      151,  151,  151,   69,  118,  151,  151,  151,   87,  151,
      151,  151,   87,  151,  151,  151,  151,  151,  151,  116,
      151,  151,  151,  119,  151,  151,  151,  119,  119,  119,
      119,  119,  119,  119,  119,  119,  119,  115,  151,  151,
      151,  151,  151,  151,  151,  151,  151,  151,  151,  134,
      134,  134,  116,  151,  151,  151,  134,  151,  151,  151,
      134,  134,  134,  134,  134,  134,  134,  134,  134,  134,
       28,   28,   28,   28,   28,   28,   28,   32,   32,   32,

       32,   32,   32,   32,   47,   47,   47,   47,   47,   47,
       47,   70,   70,   70,   70,   70,   70,   70,   74,   74,
       74,   74,   74,   74,   74,   80,   80,  151,   80,   80,
       80,   80,   82,  151,  151,  151,  151,   82,   83,   83,
       85,   85,   85,  151,   85,   85,   85,   91,   91,   92,
       92,   92,   92,   92,   92,   92,   94,   94,  151,   94,
       94,   94,   94,   99,   99,  106,  106,  151,  106,  151,
      106,  106,  109,  109,  151,  109,  109,  109,  109,  114,
      151,  151,  151,  114,  114,  123,  123,  151,  123,  123,
      123,  123,  126,  126,  126,  126,  126,  126,  126,   27,

      151,  151,  151,  151,  151,  151,  151,  151,  151,  151,
      151,  151,  151,  151,  151,  151,  151,  151,  151,  151,
      151,  151,  151,  151,  151,  151,  151,  151,  151,  151,
      151,  151,  151,  151,  151,  151
    } ;

static yyconst flex_int16_t yy_chk[537] =
    {   0,
        0,    0,    1,    2,    3,    4,   25,   13,   13,    3,
        4,    0,    1,    2,    3,    4,   25,   11,   11,    3,
        4,    5,   26,    5,   67,   12,   12,   11,   66,   11,
        5,    5,   26,   23,   13,   12,   67,   12,    5,   24,
       23,    5,    6,   23,    6,   11,   24,   30,   66,   24,
       30,    6,    6,   12,   35,   36,   36,   35,   41,    6,
      149,   41,    6,    7,    7,    7,    7,    7,    7,    7,
        7,    7,    7,    7,    7,    7,    7,    7,    7,    7,
        7,    7,    7,    7,    7,    7,    7,    7,    7,    7,
        7,    7,    7,    7,    7,    7,    7,    7,    7,   14,

       14,   49,   50,   52,   55,   49,   52,   53,   53,   49,
       85,   73,   62,   50,   73,   55,   76,   89,   77,   76,
       89,   55,   55,   62,   77,   85,   14,   15,   15,   15,
       15,   15,   15,   15,   15,   15,   15,   15,   15,   15,
       15,   15,   15,   15,   15,   15,   15,   15,   15,   15,
       15,   15,   15,   15,   15,   15,   15,   15,   15,   15,
       15,   15,   15,   17,   63,   17,   88,   17,   17,   17,
       64,   17,   17,   17,   78,   63,   64,   88,   17,   82,
       17,   63,   63,   78,  100,  108,  102,  148,  115,  147,
       64,   82,   82,   82,  108,   17,   19,   86,  102,  145,

       95,   86,   19,  115,  100,   86,   19,   95,   95,   96,
      110,  140,   86,  118,   19,   96,  110,  118,   19,   19,
       19,   19,   19,   19,   19,   19,   19,   19,   20,   96,
      111,  113,  117,  121,   20,  120,  117,  139,   20,  111,
      117,  120,  121,  113,  113,  113,   20,  117,  135,  131,
       20,   20,   20,   20,   20,   20,   20,   20,   20,   20,
       21,  125,  130,  133,  129,  138,   21,  133,  125,  125,
       21,  133,  138,  138,  128,  126,   21,  124,  123,  116,
      112,  105,  104,   21,  101,   94,   92,   84,   81,   72,
       69,   21,   22,   68,   60,   57,   51,   48,   22,   40,

       34,   27,   22,    0,    0,    0,    0,    0,   22,    0,
        0,    0,    0,    0,    0,   22,    0,    0,    0,    0,
        0,    0,    0,   22,   87,    0,    0,    0,   87,    0,
        0,    0,   87,    0,    0,    0,    0,    0,    0,   87,
        0,    0,    0,   87,    0,    0,    0,   87,   87,   87,
       87,   87,   87,   87,   87,   87,   87,  119,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,  119,
      119,  119,  119,    0,    0,    0,  119,    0,    0,    0,
      119,  119,  119,  119,  119,  119,  119,  119,  119,  119,
      152,  152,  152,  152,  152,  152,  152,  153,  153,  153,

      153,  153,  153,  153,  154,  154,  154,  154,  154,  154,
      154,  155,  155,  155,  155,  155,  155,  155,  156,  156,
      156,  156,  156,  156,  156,  157,  157,    0,  157,  157,
      157,  157,  158,    0,    0,    0,    0,  158,  159,  159,
      160,  160,  160,    0,  160,  160,  160,  161,  161,  162,
      162,  162,  162,  162,  162,  162,  163,  163,    0,  163,
      163,  163,  163,  164,  164,  165,  165,    0,  165,    0,
      165,  165,  166,  166,    0,  166,  166,  166,  166,  167,
        0,    0,    0,  167,  167,  168,  168,    0,  168,  168,
      168,  168,  169,  169,  169,  169,  169,  169,  169,  151,

      151,  151,  151,  151,  151,  151,  151,  151,  151,  151,
      151,  151,  151,  151,  151,  151,  151,  151,  151,  151,
      151,  151,  151,  151,  151,  151,  151,  151,  151,  151,
      151,  151,  151,  151,  151,  151
    } ;

extern int defargsYY_flex_debug;
int defargsYY_flex_debug = 0;

static yy_state_type *yy_state_buf=0, *yy_state_ptr=0;
static char *yy_full_match;
static int yy_lp;
static int yy_looking_for_trail_begin = 0;
static int yy_full_lp;
static int *yy_full_state;
#define YY_TRAILING_MASK 0x2000
#define YY_TRAILING_HEAD_MASK 0x4000
#define REJECT \
{ \
*yy_cp = (yy_hold_char); /* undo effects of setting up defargsYYtext */ \
yy_cp = (yy_full_match); /* restore poss. backed-over text */ \
(yy_lp) = yy_full_lp; /* restore orig. accepting pos. */ \
(yy_state_ptr) = yy_full_state; /* restore orig. state */ \
yy_current_state = *(yy_state_ptr); /* restore curr. state */ \
++(yy_lp); \
goto find_rule; \
}

#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *defargsYYtext;
#line 1 "defargs.l"
/******************************************************************************
 *
 * $Id: declinfo.l,v 1.1 1998/09/09 21:32:20 root Exp $
 *
 * Copyright (C) 1997-2008 by Dimitri van Heesch.
 *
 * Permission to use, copy, modify, and distribute this software and its
 * documentation under the terms of the GNU General Public License is hereby 
 * granted. No representations are made about the suitability of this software 
 * for any purpose. It is provided "as is" without express or implied warranty.
 * See the GNU General Public License for more details.
 *
 * Documents produced by Doxygen are derivative works derived from the
 * input used in their production; they are not affected by this license.
 *
 */
/*! \file
 *  This scanner is used to convert a string into a list of function or 
 *  template arguments. Each parsed argument results in a Argument struct,
 *  that is put into an ArgumentList in declaration order.
 *  Comment blocks for arguments can also be included in the string.
 *  The argument string does not contain new-lines (except inside any
 *  comment blocks).
 *  An Argument consists of the string fields: 
 *                 type,name,default value, and documentation
 *  The Argument list as a whole can be pure, constant or volatile.
 *
 *  Examples of input strings are:
 *  \code
 *    "(int a,int b) const"
 *    "(const char *s="hello world",int=5) = 0"
 *    "<class T,class N>"
 *    "(char c,const char)"
 *  \endcode
 *
 *  Note: It is not always possible to distinguish between the name and 
 *        type of an argument. In case of doubt the name is added to the
 *        type, and the matchArgumentList in util.cpp is be used to
 *        further determine the correct separation.
 */
#line 44 "defargs.l"

/*
 *	includes
 */
#include "qtbc.h"
#include <stdio.h>
//#include <iostream.h>
#include <assert.h>
#include <ctype.h>
#include <qregexp.h>

#include "defargs.h"
#include "entry.h"
#include "util.h"
  
#define YY_NEVER_INTERACTIVE 1
  
/* -----------------------------------------------------------------
 *	state variables
 */
static const char      *g_inputString;
static int	        g_inputPosition;
static ArgumentList    *g_argList;
static QCString        *g_copyArgValue;
static QCString         g_curArgTypeName;
static QCString         g_curArgDefValue;
static QCString		g_curArgName;
static QCString		g_curArgDocs;
static QCString		g_curArgAttrib;
static QCString		g_curArgArray;
static QCString		g_extraTypeChars;
static int              g_argRoundCount;
static int              g_argSharpCount;
static int              g_argCurlyCount;
static int              g_readArgContext;
static int              g_lastDocContext;
static int              g_lastDocChar;

/* -----------------------------------------------------------------
 */
#undef	YY_INPUT
#define	YY_INPUT(buf,result,max_size) result=yyread(buf,max_size);

static int yyread(char *buf,int max_size)
{
    int c=0;
    while( c < max_size && g_inputString[g_inputPosition] )
    {
	*buf = g_inputString[g_inputPosition++] ;
	c++; buf++;
    }
    return c;
}













#line 772 "<stdout>"

#define INITIAL 0
#define Start 1
#define CopyArgString 2
#define CopyArgRound 3
#define CopyArgRound2 4
#define CopyArgSharp 5
#define CopyArgCurly 6
#define ReadFuncArgType 7
#define ReadFuncArgDef 8
#define ReadFuncArgPtr 9
#define FuncQual 10
#define ReadDocBlock 11
#define ReadDocLine 12

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals (void );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int defargsYYwrap (void );
#else
extern int defargsYYwrap (void );
#endif
#endif

    static void yyunput (int c,char *buf_ptr  );
    
#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#define YY_READ_BUF_SIZE 262144
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO (void) fwrite( defargsYYtext, defargsYYleng, 1, defargsYYout )
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		size_t n; \
		for ( n = 0; n < max_size && \
			     (c = getc( defargsYYin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( defargsYYin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, defargsYYin))==0 && ferror(defargsYYin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(defargsYYin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int defargsYYlex (void);

#define YY_DECL int defargsYYlex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after defargsYYtext and defargsYYleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    
#line 119 "defargs.l"


#line 940 "<stdout>"

	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

        /* Create the reject buffer large enough to save one state per allowed character. */
        if ( ! (yy_state_buf) )
            (yy_state_buf) = (yy_state_type *)defargsYYalloc(YY_STATE_BUF_SIZE  );

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! defargsYYin )
			defargsYYin = stdin;

		if ( ! defargsYYout )
			defargsYYout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			defargsYYensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				defargsYY_create_buffer(defargsYYin,YY_BUF_SIZE );
		}

		defargsYY_load_buffer_state( );
		}

	while ( 1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of defargsYYtext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);

		(yy_state_ptr) = (yy_state_buf);
		*(yy_state_ptr)++ = yy_current_state;

yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 152 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			*(yy_state_ptr)++ = yy_current_state;
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 500 );

yy_find_action:
		yy_current_state = *--(yy_state_ptr);
		(yy_lp) = yy_accept[yy_current_state];
find_rule: /* we branch to this label when backing up */
		for ( ; ; ) /* until we find what rule we matched */
			{
			if ( (yy_lp) && (yy_lp) < yy_accept[yy_current_state + 1] )
				{
				yy_act = yy_acclist[(yy_lp)];
				if ( yy_act & YY_TRAILING_HEAD_MASK ||
				     yy_looking_for_trail_begin )
					{
					if ( yy_act == yy_looking_for_trail_begin )
						{
						yy_looking_for_trail_begin = 0;
						yy_act &= ~YY_TRAILING_HEAD_MASK;
						break;
						}
					}
				else if ( yy_act & YY_TRAILING_MASK )
					{
					yy_looking_for_trail_begin = yy_act & ~YY_TRAILING_MASK;
					yy_looking_for_trail_begin |= YY_TRAILING_HEAD_MASK;
					}
				else
					{
					(yy_full_match) = yy_cp;
					yy_full_state = (yy_state_ptr);
					yy_full_lp = (yy_lp);
					break;
					}
				++(yy_lp);
				goto find_rule;
				}
			--yy_cp;
			yy_current_state = *--(yy_state_ptr);
			(yy_lp) = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
case 1:
YY_RULE_SETUP
#line 121 "defargs.l"
{ BEGIN(ReadFuncArgType); }
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 123 "defargs.l"
{
  					  g_curArgTypeName+=" ";
  					}
	YY_BREAK
case 3:
/* rule 3 can match eol */
YY_RULE_SETUP
#line 126 "defargs.l"
{ 
					  if (g_curArgTypeName.stripWhiteSpace().isEmpty())
					  {
					    g_curArgAttrib=defargsYYtext; // for M$-IDL
					  }
					  else // array type
					  {
					    g_curArgArray+=defargsYYtext;
					  }
					}
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 136 "defargs.l"
{ g_curArgDefValue+=defargsYYtext; }
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 137 "defargs.l"
{ g_curArgDefValue+=defargsYYtext; }
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 138 "defargs.l"
{ g_curArgDefValue+=defargsYYtext; }
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 139 "defargs.l"
{
  					  g_curArgDefValue+=*defargsYYtext;
  					  BEGIN( CopyArgString );
  					}
	YY_BREAK
case 8:
/* rule 8 can match eol */
YY_RULE_SETUP
#line 143 "defargs.l"
{ 
  					  // function pointer as argument
					  g_curArgTypeName+=defargsYYtext;
					  //g_curArgTypeName=g_curArgTypeName.simplifyWhiteSpace();
					  BEGIN( ReadFuncArgPtr );
  					}
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 149 "defargs.l"
{
					  g_curArgName=defargsYYtext;
  					}
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 152 "defargs.l"
{ // function pointer
					  g_curArgTypeName+=defargsYYtext;
					  //g_curArgTypeName=g_curArgTypeName.simplifyWhiteSpace();
					  g_readArgContext = ReadFuncArgType;
					  g_copyArgValue=&g_curArgTypeName;
					  g_argRoundCount=0;
					  BEGIN( CopyArgRound2 );
					}
	YY_BREAK
case 11:
*yy_cp = (yy_hold_char); /* undo effects of setting up defargsYYtext */
(yy_c_buf_p) = yy_cp = yy_bp + 1;
YY_DO_BEFORE_ACTION; /* set up defargsYYtext again */
YY_RULE_SETUP
#line 160 "defargs.l"
{ // pointer to fixed size array
					  g_curArgTypeName+=defargsYYtext;
					  g_curArgTypeName+=g_curArgName;
					  //g_curArgTypeName=g_curArgTypeName.simplifyWhiteSpace();
					  BEGIN( ReadFuncArgType );
					}
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 166 "defargs.l"
{ // redundant braces detected / remove them
					  int i=g_curArgTypeName.findRev('('),l=g_curArgTypeName.length();
					  if (i!=-1)
					    g_curArgTypeName=g_curArgTypeName.left(i)+
					                   g_curArgTypeName.right(l-i-1);
					  g_curArgTypeName+=g_curArgName;
					  BEGIN( ReadFuncArgType );
					}
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 174 "defargs.l"
{ // handle operators in defargs
  					  g_curArgTypeName+=defargsYYtext;
  					}
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 177 "defargs.l"
{	 
					  if (YY_START==ReadFuncArgType)
					  {
					    g_curArgTypeName+=*defargsYYtext;
					    g_copyArgValue=&g_curArgTypeName;
					  }
					  else // YY_START==ReadFuncArgDef
					  {
					    g_curArgDefValue+=*defargsYYtext;
					    g_copyArgValue=&g_curArgDefValue;
					  }
					  g_readArgContext = YY_START; 
					  if (*defargsYYtext=='(')
					  {
					    g_argRoundCount=0; 
					    BEGIN( CopyArgRound ); 
					  }
					  else if (*defargsYYtext=='{')
					  {
					    g_argCurlyCount=0; 
					    BEGIN( CopyArgCurly ); 
					  }
					  else // defargsYYtext=='<'
					  {
					    g_argSharpCount=0; 
					    BEGIN( CopyArgSharp ); 
					  }
					}
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 205 "defargs.l"
{
  					  g_argRoundCount++;
					  *g_copyArgValue += *defargsYYtext;
  					}
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 209 "defargs.l"
{
					  *g_copyArgValue += defargsYYtext;
					  if (g_argRoundCount>0) 
					  {
					    g_argRoundCount--;
					  }
					  else 
					  {
					    if (YY_START==CopyArgRound2)
					    {
					      *g_copyArgValue+=" "+g_curArgName;
					    }
					    BEGIN( g_readArgContext );
					  }
  					}
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 224 "defargs.l"
{
  					  g_argSharpCount++;
					  *g_copyArgValue += *defargsYYtext;
  					}
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 228 "defargs.l"
{
					  *g_copyArgValue += *defargsYYtext;
					  if (g_argSharpCount>0) g_argSharpCount--;
					  else BEGIN( g_readArgContext );
  					}
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 233 "defargs.l"
{
  					  g_argCurlyCount++;
					  *g_copyArgValue += *defargsYYtext;
  					}
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 237 "defargs.l"
{
					  *g_copyArgValue += *defargsYYtext;
					  if (g_argCurlyCount>0) g_argCurlyCount--;
					  else BEGIN( g_readArgContext );
  					}
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 242 "defargs.l"
{
					  g_curArgDefValue+=defargsYYtext;
  					}
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 245 "defargs.l"
{
					  g_curArgDefValue+=*defargsYYtext;
					  BEGIN( ReadFuncArgDef );
  					}
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 249 "defargs.l"
{
					  BEGIN( ReadFuncArgDef );
  					}
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 252 "defargs.l"
{
					  g_lastDocContext=YY_START;
					  g_lastDocChar=*defargsYYtext;  
					  QCString text=defargsYYtext;
					  if (text.find("//")!=-1)
					    BEGIN( ReadDocLine );
					  else
					    BEGIN( ReadDocBlock );
  					}
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 261 "defargs.l"
{
  					  if (*defargsYYtext==')' && g_curArgTypeName.stripWhiteSpace().isEmpty())
					  {
					    g_curArgTypeName+=*defargsYYtext;
					    BEGIN(FuncQual);
					  }
					  else
					  {
					    g_curArgTypeName=removeRedundantWhiteSpace(g_curArgTypeName);
					    g_curArgDefValue=g_curArgDefValue.stripWhiteSpace();
					    //printf("curArgType=`%s' curArgDefVal=`%s'\n",g_curArgTypeName.data(),g_curArgDefValue.data());
					    int l=g_curArgTypeName.length();
					    if (l>0)
					    {
					      int i=l-1;
					      while (i>=0 && (isspace((uchar)g_curArgTypeName.at(i)) || g_curArgTypeName.at(i)=='.')) i--;
					      while (i>=0 && isId(g_curArgTypeName.at(i))) i--;
					      //printf("g_curArgTypeName=`%s' i=%d\n",g_curArgTypeName.data(),i);
					      Argument *a = new Argument; 
					      a->attrib = g_curArgAttrib.copy();
					      //printf("a->type=%s a->name=%s i=%d l=%d\n",
					      //	a->type.data(),a->name.data(),i,l);
					      a->array.resize(0);
					      if (i==l-1 && g_curArgTypeName.at(i)==')') // function argument
					      {
						int bi=g_curArgTypeName.find('(');
						int fi=bi-1;
						//printf("func arg fi=%d\n",fi);
						while (fi>=0 && isId(g_curArgTypeName.at(fi))) fi--;
						if (fi>=0)
						{
						  a->type  = g_curArgTypeName.left(fi+1);
						  a->name  = g_curArgTypeName.mid(fi+1,bi-fi-1).stripWhiteSpace();
						  a->array = g_curArgTypeName.right(l-bi);
						}
						else
						{
						  a->type = g_curArgTypeName;
						}
					      }
					      else if (i>=0 && g_curArgTypeName.at(i)!=':')
					      { // type contains a name
						a->type = removeRedundantWhiteSpace(g_curArgTypeName.left(i+1));
						a->name = g_curArgTypeName.right(l-i-1).stripWhiteSpace();

						// if the type becomes a type specifier only then we make a mistake
						// and need to correct it to avoid seeing a nameless parameter
						// "struct A" as a parameter with type "struct" and name "A".
						int sv=0;
						if (a->type.left(6)=="const ") sv=6;
						else if (a->type.left(8)=="volatile ") sv=9;
						if (a->type.mid(sv)=="struct"    || 
						    a->type.mid(sv)=="union"     || 
						    a->type.mid(sv)=="class"     || 
						    a->type.mid(sv)=="typename"  || 
						    a->type=="const" || a->type=="volatile")
						{ 
						  a->type = a->type + " " + a->name;
						  a->name.resize(0);
						}
					      }
					      else // assume only the type was specified, try to determine name later 
					      {
						a->type = removeRedundantWhiteSpace(g_curArgTypeName);  
					      }
					      a->array  += removeRedundantWhiteSpace(g_curArgArray);
					      //printf("array=%s\n",a->array.data());
					      int alen = a->array.length();
					      if (alen>2 && a->array.at(0)=='(' && 
						            a->array.at(alen-1)==')') // fix-up for int *(a[10])
					      {
						int i=a->array.find('[')-1;
						a->array = a->array.mid(1,alen-2);
						if (i>0 && a->name.isEmpty())
						{
						  a->name  = a->array.left(i).stripWhiteSpace();
						  a->array = a->array.mid(i);
						}
					      }
					      a->defval = g_curArgDefValue.copy();
					      //printf("a->type=%s a->name=%s a->defval=\"%s\"\n",a->type.data(),a->name.data(),a->defval.data());
					      a->docs   = g_curArgDocs.stripWhiteSpace();
					      //printf("Argument `%s' `%s' adding docs=`%s'\n",a->type.data(),a->name.data(),a->docs.data());
					      g_argList->append(a);
					    }
					    g_curArgAttrib.resize(0);
					    g_curArgTypeName.resize(0);
					    g_curArgDefValue.resize(0);
					    g_curArgArray.resize(0);
					    g_curArgDocs.resize(0);
					    if (*defargsYYtext==')')
					    {
					      BEGIN(FuncQual);
					      //printf(">>> end of argument list\n");
					    }
					    else
					    {
					      BEGIN( ReadFuncArgType );
					    }
					  }
  					}
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 362 "defargs.l"
{ 
  					  QCString name=defargsYYtext; //resolveDefines(defargsYYtext);
					  if (YY_START==ReadFuncArgType && g_curArgArray=="[]") // Java style array
					  {
					    g_curArgTypeName+=" []";
					    g_curArgArray.resize(0);
					  }
					  //printf("resolveName `%s'->`%s'\n",defargsYYtext,name.data());
  					  g_curArgTypeName+=name;
					}
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 372 "defargs.l"
{ 
  					  g_curArgTypeName+=*defargsYYtext;
					}
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 376 "defargs.l"
{
  					  g_curArgDefValue+=defargsYYtext;
  					}
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 379 "defargs.l"
{
					  g_curArgDefValue+=*defargsYYtext;
  					}
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 382 "defargs.l"
{
  					  QCString name=defargsYYtext; //resolveDefines(defargsYYtext);
					  *g_copyArgValue+=name;
					}
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 386 "defargs.l"
{
					  *g_copyArgValue += *defargsYYtext;
					}
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 389 "defargs.l"
{ 
					  g_argList->constSpecifier=TRUE;
					}
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 392 "defargs.l"
{ 
					  g_argList->volatileSpecifier=TRUE;
					}
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 395 "defargs.l"
{ 
					  g_argList->pureSpecifier=TRUE;
					}
	YY_BREAK
case 35:
/* rule 35 can match eol */
YY_RULE_SETUP
#line 398 "defargs.l"
{ // for functions returning a pointer to an array, 
                                          // i.e. ")[]" in "int (*f(int))[4]" with argsString="(int))[4]"
  					  g_extraTypeChars=defargsYYtext;
  					}
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 402 "defargs.l"
{
  					  g_curArgDocs+=defargsYYtext;
  					}
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 405 "defargs.l"
{
  					  g_curArgDocs+=defargsYYtext;
  					}
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 408 "defargs.l"
{ 
  					  if (g_lastDocChar!=0)
					    unput(g_lastDocChar);
  					  BEGIN(g_lastDocContext); 
					}
	YY_BREAK
case 39:
/* rule 39 can match eol */
YY_RULE_SETUP
#line 413 "defargs.l"
{
  					  if (g_lastDocChar!=0)
					    unput(g_lastDocChar);
					  BEGIN(g_lastDocContext);
  					}
	YY_BREAK
case 40:
/* rule 40 can match eol */
YY_RULE_SETUP
#line 418 "defargs.l"
{
  					  g_curArgDocs+=*defargsYYtext;
  					}
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 421 "defargs.l"
{
  					  g_curArgDocs+=*defargsYYtext;
  					}
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 424 "defargs.l"
{
  					  g_lastDocContext=YY_START;
					  g_lastDocChar=0;  
					  if (defargsYYtext[1]=='/')
					    BEGIN( ReadDocLine );
					  else
  					    BEGIN( ReadDocBlock );
  					}
	YY_BREAK
case 43:
/* rule 43 can match eol */
YY_RULE_SETUP
#line 432 "defargs.l"

	YY_BREAK
case 44:
YY_RULE_SETUP
#line 433 "defargs.l"

	YY_BREAK
case 45:
YY_RULE_SETUP
#line 435 "defargs.l"
ECHO;
	YY_BREAK
#line 1551 "<stdout>"
			case YY_STATE_EOF(INITIAL):
			case YY_STATE_EOF(Start):
			case YY_STATE_EOF(CopyArgString):
			case YY_STATE_EOF(CopyArgRound):
			case YY_STATE_EOF(CopyArgRound2):
			case YY_STATE_EOF(CopyArgSharp):
			case YY_STATE_EOF(CopyArgCurly):
			case YY_STATE_EOF(ReadFuncArgType):
			case YY_STATE_EOF(ReadFuncArgDef):
			case YY_STATE_EOF(ReadFuncArgPtr):
			case YY_STATE_EOF(FuncQual):
			case YY_STATE_EOF(ReadDocBlock):
			case YY_STATE_EOF(ReadDocLine):
				yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed defargsYYin at a new source and called
			 * defargsYYlex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = defargsYYin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( defargsYYwrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * defargsYYtext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of defargsYYlex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = (yytext_ptr);
	register int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			YY_FATAL_ERROR(
"input buffer overflow, can't enlarge buffer because scanner uses REJECT" );

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			defargsYYrestart(defargsYYin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    
	yy_current_state = (yy_start);

	(yy_state_ptr) = (yy_state_buf);
	*(yy_state_ptr)++ = yy_current_state;

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 152 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		*(yy_state_ptr)++ = yy_current_state;
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	register int yy_is_jam;
    
	register YY_CHAR yy_c = 1;
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 152 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 151);
	if ( ! yy_is_jam )
		*(yy_state_ptr)++ = yy_current_state;

	return yy_is_jam ? 0 : yy_current_state;
}

    static void yyunput (int c, register char * yy_bp )
{
	register char *yy_cp;
    
    yy_cp = (yy_c_buf_p);

	/* undo effects of setting up defargsYYtext */
	*yy_cp = (yy_hold_char);

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		register int number_to_move = (yy_n_chars) + 2;
		register char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		register char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

	(yytext_ptr) = yy_bp;
	(yy_hold_char) = *yy_cp;
	(yy_c_buf_p) = yy_cp;
}

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					defargsYYrestart(defargsYYin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( defargsYYwrap( ) )
						return 0;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve defargsYYtext */
	(yy_hold_char) = *++(yy_c_buf_p);

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void defargsYYrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        defargsYYensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            defargsYY_create_buffer(defargsYYin,YY_BUF_SIZE );
	}

	defargsYY_init_buffer(YY_CURRENT_BUFFER,input_file );
	defargsYY_load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void defargsYY_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		defargsYYpop_buffer_state();
	 *		defargsYYpush_buffer_state(new_buffer);
     */
	defargsYYensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	defargsYY_load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (defargsYYwrap()) processing, but the only time this flag
	 * is looked at is after defargsYYwrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void defargsYY_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	defargsYYin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE defargsYY_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) defargsYYalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in defargsYY_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) defargsYYalloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in defargsYY_create_buffer()" );

	b->yy_is_our_buffer = 1;

	defargsYY_init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with defargsYY_create_buffer()
 * 
 */
    void defargsYY_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		defargsYYfree((void *) b->yy_ch_buf  );

	defargsYYfree((void *) b  );
}

#ifndef __cplusplus
extern int isatty (int );
#endif /* __cplusplus */
    
/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a defargsYYrestart() or at EOF.
 */
    static void defargsYY_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	defargsYY_flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then defargsYY_init_buffer was _probably_
     * called from defargsYYrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void defargsYY_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		defargsYY_load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void defargsYYpush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	defargsYYensure_buffer_stack();

	/* This block is copied from defargsYY_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from defargsYY_switch_to_buffer. */
	defargsYY_load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void defargsYYpop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	defargsYY_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		defargsYY_load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void defargsYYensure_buffer_stack (void)
{
	int num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		(yy_buffer_stack) = (struct yy_buffer_state**)defargsYYalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		
		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)defargsYYrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE defargsYY_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) defargsYYalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in defargsYY_scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	defargsYY_switch_to_buffer(b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to defargsYYlex() will
 * scan from a @e copy of @a str.
 * @param str a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       defargsYY_scan_bytes() instead.
 */
YY_BUFFER_STATE defargsYY_scan_string (yyconst char * yystr )
{
    
	return defargsYY_scan_bytes(yystr,strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to defargsYYlex() will
 * scan from a @e copy of @a bytes.
 * @param bytes the byte buffer to scan
 * @param len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE defargsYY_scan_bytes  (yyconst char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) defargsYYalloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in defargsYY_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = defargsYY_scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in defargsYY_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg )
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up defargsYYtext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		defargsYYtext[defargsYYleng] = (yy_hold_char); \
		(yy_c_buf_p) = defargsYYtext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		defargsYYleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int defargsYYget_lineno  (void)
{
        
    return defargsYYlineno;
}

/** Get the input stream.
 * 
 */
FILE *defargsYYget_in  (void)
{
        return defargsYYin;
}

/** Get the output stream.
 * 
 */
FILE *defargsYYget_out  (void)
{
        return defargsYYout;
}

/** Get the length of the current token.
 * 
 */
int defargsYYget_leng  (void)
{
        return defargsYYleng;
}

/** Get the current token.
 * 
 */

char *defargsYYget_text  (void)
{
        return defargsYYtext;
}

/** Set the current line number.
 * @param line_number
 * 
 */
void defargsYYset_lineno (int  line_number )
{
    
    defargsYYlineno = line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 * 
 * @see defargsYY_switch_to_buffer
 */
void defargsYYset_in (FILE *  in_str )
{
        defargsYYin = in_str ;
}

void defargsYYset_out (FILE *  out_str )
{
        defargsYYout = out_str ;
}

int defargsYYget_debug  (void)
{
        return defargsYY_flex_debug;
}

void defargsYYset_debug (int  bdebug )
{
        defargsYY_flex_debug = bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from defargsYYlex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = 0;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = (char *) 0;
    (yy_init) = 0;
    (yy_start) = 0;

    (yy_state_buf) = 0;
    (yy_state_ptr) = 0;
    (yy_full_match) = 0;
    (yy_lp) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    defargsYYin = stdin;
    defargsYYout = stdout;
#else
    defargsYYin = (FILE *) 0;
    defargsYYout = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * defargsYYlex_init()
     */
    return 0;
}

/* defargsYYlex_destroy is for both reentrant and non-reentrant scanners. */
int defargsYYlex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		defargsYY_delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		defargsYYpop_buffer_state();
	}

	/* Destroy the stack itself. */
	defargsYYfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    defargsYYfree ( (yy_state_buf) );
    (yy_state_buf)  = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * defargsYYlex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *defargsYYalloc (yy_size_t  size )
{
	return (void *) malloc( size );
}

void *defargsYYrealloc  (void * ptr, yy_size_t  size )
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void defargsYYfree (void * ptr )
{
	free( (char *) ptr );	/* see defargsYYrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 435 "defargs.l"



/* ----------------------------------------------------------------------------
 */

/*! Converts an argument string into an ArgumentList.
 *  \param argsString the list of Arguments.
 *  \param al a reference to resulting argument list pointer.
 */
 
void stringToArgumentList(const char *argsString,ArgumentList* al,QCString *extraTypeChars)
{
  if (al==0) return; 
  if (argsString==0) return;

  g_copyArgValue=0;
  g_curArgDocs.resize(0);
  g_curArgAttrib.resize(0);
  g_curArgArray.resize(0);
  g_extraTypeChars.resize(0);
  g_argRoundCount = 0;
  g_argSharpCount = 0;
  g_argCurlyCount = 0;
  g_lastDocChar = 0;

  g_inputString   = argsString;
  g_inputPosition = 0;
  g_curArgTypeName.resize(0);
  g_curArgDefValue.resize(0);
  g_curArgName.resize(0);
  g_argList = al;
  defargsYYrestart( defargsYYin );
  BEGIN( Start );
  defargsYYlex();
  if (extraTypeChars) *extraTypeChars=g_extraTypeChars;
  //printf("stringToArgumentList(%s) result=%s\n",argsString,argListToString(al).data());
}

#if !defined(YY_FLEX_SUBMINOR_VERSION) 
extern "C" { // some bogus code to keep the compiler happy
  void defargsYYdummy() { yy_flex_realloc(0,0); } 
}
#endif


